@@ -34,7 +34,7 @@
 Base ROS python library for manipulating ROS packages and stacks.
 """
 
-__version__ = '0.12.8'
+__version__ = '1.0.0'
 
 from .common import MANIFEST_FILE, STACK_FILE, ResourceNotFound
 from .environment import get_ros_root, get_ros_package_path, get_ros_home, \
@@ -44,3 +44,13 @@ from .rospack import RosPack, RosStack, \
      list_by_path, expand_to_packages, get_stack_version_by_dir, \
      get_package_name
 
+__all__ = ['MANIFEST_FILE', 'STACK_FILE', 'ResourceNotFound',
+        'get_ros_root', 'get_ros_package_path', 'get_ros_home',
+        'get_log_dir', 'get_test_results_dir', 'on_ros_path',
+        'get_ros_paths', 'get_etc_ros_dir', 
+        'parse_manifest_file', 'Manifest', 'InvalidManifest',
+        'RosPack', 'RosStack', 
+        'list_by_path', 'expand_to_packages', 'get_stack_version_by_dir',
+        'get_package_name',
+        ]
+
